html {
    box-sizing: border-box;
    font-size: 80%;
}

body {
    display: flex;
    color: #323232;
    background-color: #fefefe;
    font-family: 'Fira Mono',monospace;
    font-size: 1.6em;
    font-weight: 400;
    letter-spacing: .0625em;
    line-height: 1.8em;
}

main {
    margin-left: 10%;
    margin-right: 10%;
}

.container {
    max-width: 960px;
}
  
.blog-header {
    max-width: 700px;
}

*,*:after,*:before {
    box-sizing: inherit;
}


.title {
    font-weight: bold;
}

.date {
    margin-top: 5px;
}


@media only screen and (min-device-width:320px) and (max-device-width:480px) {
body {
    font-size: 1.4em;
    line-height: 1.6em;
}   
}

a {
    color: #000;
    text-decoration: underline;
}

a:focus,a:hover {
    text-decoration: underline;
}

p {
    margin: 1.6rem 0 1.6rem 0;
}

p a {
    font-weight: 400;
    color: #000;
    text-decoration: underline;
    text-underline-position: under;
}

p a:focus,p a:hover {
    color: #000000;
}

h1,h2,h3,h4,h5,h6 {
    color: #000;
    text-transform: uppercase;
    letter-spacing: .0625em;
    margin: 3.2rem 0 1.6rem 0;
}

h1 {
    font-size: 3.2rem;
    line-height: 3.2rem;
}

@media only screen and (min-device-width:320px) and (max-device-width:480px) {
h1 {
    font-size: 2.8rem;
    line-height: 2.8rem;
}
}

h2 {
    font-size: 2.8rem;
    line-height: 2.8rem;
}

@media only screen and (min-device-width:320px) and (max-device-width:480px) {
h2 {
    font-size: 2.4rem;
    line-height: 2.4rem;
}
}

h3 {
    font-size: 2.4rem;
    line-height: 2.4rem;
}

@media only screen and (min-device-width:320px) and (max-device-width:480px) {
h3 {
    font-size: 2rem;
    line-height: 2rem;
}
}

h4 {
    font-size: 2.2rem;
    line-height: 2.2rem;
}

@media only screen and (min-device-width:320px) and (max-device-width:480px) {
h4 {
    font-size: 1.8rem;
    line-height: 1.8rem;
}
}

h5 {
    font-size: 2rem;
    line-height: 2rem;
}

@media only screen and (min-device-width:320px) and (max-device-width:480px) {
h5 {
    font-size: 1.6rem;
    line-height: 1.6rem;
}
}

h6 {
    font-size: 1.4rem;
    line-height: 1.4rem;
}

blockquote {
    border-left: 2px solid #dcdcdc;
    padding-left: 1.6rem;
    font-style: italic;
}

th,td {
    padding: 1.6rem;
}

table {
    border-collapse: collapse;
}

table td,table th {
    border: 2px solid #000;
}

table tr:first-child th {
    border-top: 0;
}

table tr:last-child td {
    border-bottom: 0;
}

table tr td:first-child,table tr th:first-child {
    border-left: 0;
}

table tr td:last-child,table tr th:last-child {
    border-right: 0;
}

.wrapper {
    display: flex;
    flex-direction: column;
    min-height: 100vh;
    width: 100%;
}

.container {
    margin: 0 auto;
    max-width: 120rem;
    width: 100%;
    padding-left: 2rem;
    padding-right: 2rem;
}

.navigation {
    height: 6rem;
    width: 100%;
}

.navigation a {
    display: inline;
    font-size: 1.6rem;
    text-transform: uppercase;
    line-height: 6rem;
    letter-spacing: .1rem;
}

@media only screen and (min-device-width:320px) and (max-device-width:480px) {
.navigation a {
    font-size: 1.4rem;
}
}

.navigation ul {
    list-style: none;
    margin-bottom: 0;
    margin-top: 0;
}

.navigation ul li {
    float: left;
    margin: 0;
    position: relative;
}

.navigation ul li a {
    margin-left: 1rem;
    margin-right: 1rem;
}

.content {
    flex: 1;
    margin-top: 1.6rem;
    margin-bottom: 3.2rem;
}

.content article header {
    margin-top: 3.2rem;
    margin-bottom: 3.2rem;
}

.content article header h1,.content article header h2 {
    margin: 0;
}

.content article header h2 {
    margin-top: 1rem;
    font-size: 1.8rem;
    color: #323232;
}

@media only screen and (min-device-width:320px) and (max-device-width:480px) {
.content article header h2 {
    font-size: 1.6rem;
}
}

.list ul {
    margin: 3.2rem 0 3.2rem 0;
    list-style: none;
    padding: 0;
}

.list ul li {
    font-size: 1.6rem;
}

@media only screen and (min-device-width:320px) and (max-device-width:480px) {
.list ul li {
    font-size: 1.4rem;
    margin: 1.6rem 0 1.6rem 0;
}
}

.list ul li span {
    display: inline-block;
    text-align: right;
    width: 25rem;
    margin-right: 3rem;
}

@media only screen and (min-device-width:320px) and (max-device-width:480px) {
.list ul li span {
    display: block;
    text-align: left;
}
}

.list ul li a {
    text-transform: uppercase;
}

.pagination {
margin-top: 6rem;
text-align: center;
}

.pagination li {
    display: inline;
    text-align: center;
}

.pagination li span {
margin: 0;
text-align: center;
width: 3.2rem;
}

.pagination li a span {
    margin: 0;
    text-align: center;
    width: 3.2rem;
}

.centered {
    display: flex;
    height: 100%;
    align-items: center;
    justify-content: center;
}

.centered .about {
    text-align: center;
}

.centered .about h1 {
    margin-top: 2rem;
    margin-bottom: .5rem;
}

.centered .about h2 {
    margin-top: 1rem;
    margin-bottom: .5rem;
    font-size: 2.4rem;
}

@media only screen and (min-device-width:320px) and (max-device-width:480px) {
.centered .about h2 {
    font-size: 2rem;
}
}

.centered .about ul {
    list-style: none;
    margin: 3rem 0 1rem 0;
    padding: 0;
}

.centered .about ul li {
    display: inline-block;
    position: relative;
}

.centered .about ul li a {
    text-transform: uppercase;
    margin-left: 1rem;
    margin-right: 1rem;
    font-size: 1.6rem;
}

@media only screen and (min-device-width:320px) and (max-device-width:480px) {
.centered .about ul li a {
    font-size: 1.4rem;
}
}

.centered .error {
    text-align: center;
}

.centered .error h1 {
    margin-top: 2rem;
    margin-bottom: .5rem;
    font-size: 4.6rem;
}

@media only screen and (min-device-width:320px) and (max-device-width:480px) {
.centered .error h1 {
    font-size: 3.2rem;
}
}

.centered .error h2 {
    margin-top: 2rem;
    margin-bottom: 3.2rem;
    font-size: 3.2rem;
}

@media only screen and (min-device-width:320px) and (max-device-width:480px) {
.centered .error h2 {
    font-size: 2.8rem;
}
}

.footer {
    height: 6rem;
    width: 100%;
    text-align: center;
    line-height: 6rem;
}

.float-right {
    float: right;
}

.float-left {
    float: left;
}

.bd-placeholder-img {
    font-size: 1.125rem;
    text-anchor: middle;
    -webkit-user-select: none;
    -moz-user-select: none;
    user-select: none;
}

@media (min-width: 768px) {
    .bd-placeholder-img-lg {
    font-size: 3.5rem;
    }
}

.b-example-divider {
    height: 3rem;
    background-color: rgba(0, 0, 0, .1);
    border: solid rgba(0, 0, 0, .15);
    border-width: 1px 0;
    box-shadow: inset 0 .5em 1.5em rgba(0, 0, 0, .1), inset 0 .125em .5em rgba(0, 0, 0, .15);
}

.b-example-vr {
    flex-shrink: 0;
    width: 1.5rem;
    height: 100vh;
}

.bi {
    vertical-align: -.125em;
    fill: currentColor;
}

.nav-scroller {
    position: relative;
    z-index: 2;
    height: 2.75rem;
    overflow-y: hidden;
}

.nav-scroller .nav {
    display: flex;
    flex-wrap: nowrap;
    padding-bottom: 1rem;
    margin-top: -1px;
    overflow-x: auto;
    text-align: center;
    white-space: nowrap;
    -webkit-overflow-scrolling: touch;
}

.home {
    color: #ffffff !important;
    text-align: center;
}

.home-icon {
    width: 35px;
    height: 35px;
    opacity: 1.0;
}

.post-img {
    max-width: 100%;
    display: block;
    margin-left: auto;
    margin-right: auto;
    filter: grayscale(100%);
}

.post-list {
    font-size: 80%;
    font-weight: bold;
    text-decoration: none;
}

.post-date-list {
    font-size: 80%;
    text-decoration: none;
}

.home-icon:hover {
    opacity: 0.5;
}

figcaption {
    font-size: 75%;
    font-weight: bold;
    text-align: center;
}

code {
    background-color: #000;
    color: #fefefe;
    padding: .4rem .8rem .4rem .8rem;
}

pre {
    margin: 1.6rem 0 1rem 0;
    padding: 1.6rem;
    overflow-x: auto;
    color:#e5e5e5;
    background-color:#000;
    tab-size: 2;
    font-size: .775em;
    line-height: 30px;
}
